/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Drag de Go code.
 *
 * The Initial Developer of the Original Code is
 * Yukichi Kamata.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var nsCI = Components.interfaces;
var searchEngineDialog = {
	Search : null,
	view : null,
	data : null,
	init: function(){
		this.data = window.arguments[0].value;
		this.view = new EngineView(new EngineStore(ddg_Search));
		var tree = document.getElementById("engineList");
		tree.view = this.view;
		window.arguments[0].value = null;
		if(this.data){
			var index = this.view._engineStore._getIndexForEngine(this.data);
			this.view.selection.select(index);
		}
	},
	
	onAccept : function(){
		var plug = this.view.selectedEngine;
		var retVals = window.arguments[0];
		if(plug)
			retVals.value = encodeURIComponent(plug.name);
	}
}

function EngineStore(Search) {
	this._engines = Search.getEngines();
}

EngineStore.prototype = {
	_engines: null,
	
	get engines() {
		return this._engines;
	},
		
	_getIndexForEngine: function (aEngine) {
		aEngine = decodeURIComponent(aEngine);
		for (var i in this._engines){
			if(this._engines[i].name == aEngine)
				return i;
		}
		return -1;
	}
}

function EngineView(aEngineStore) {
	this._engineStore = aEngineStore;
}
EngineView.prototype = {
	_engineStore: null,
	tree: null,
	
	get lastIndex() {
		return this.rowCount - 1;
	},
	get selectedIndex() {
		var seln = this.selection;
		if (seln.getRangeCount() > 0) {
			var min = { };
			seln.getRangeAt(0, min, { });
			return min.value;
		}
		return -1;
	},
	get selectedEngine() {
		return this._engineStore.engines[this.selectedIndex];
	},
	
	invalidate: function () {
		this.tree.invalidate();
	},
	
	ensureRowIsVisible: function (index) {
		this.tree.ensureRowIsVisible(index);
	},
	
	// nsITreeView
	get rowCount() {
		return this._engineStore.engines.length;
	},
	
	getImageSrc: function(index, column) {
		if (column.id == "engineName" && this._engineStore.engines[index].iconpath)
			return this._engineStore.engines[index].iconpath;
		return "";
	},
	
	getCellText: function(index, column) {
		if (column.id == "engineName")
			return this._engineStore.engines[index].name;
		return "";
	},
	
	setTree: function(tree) {
		this.tree = tree;
	},
	
	selection: null,
	getRowProperties: function(index, properties) { },
	getCellProperties: function(index, column, properties) { },
	getColumnProperties: function(column, properties) { },
	getLevel: function(row){ return 0; },
	isContainer: function(index) { return false; },
	isSeparator: function(index) { return false; },
	isSorted: function(index) { return false; }
};
 